@@ -1,14 +1,12 @@
 [+ autogen5 template +]
+[+INCLUDE (string-append "licenses/" (get "License") ".tpl") \+]
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * main.cc
- * Copyright (C) [+Author+] [+(shell "date +%Y")+] <[+Email+]>
+ * Copyright (C) [+(shell "date +%Y")+] [+Author+] <[+Email+]>
  * 
-[+CASE (get "License") +]
-[+ == "BSD"  +][+(bsd  (get "Name") (get "Author") " * ")+]
-[+ == "LGPL" +][+(lgpl (get "Name") (get "Author") " * ")+]
-[+ == "GPL"  +][+(gpl  (get "Name")                " * ")+]
-[+ESAC+] */
+[+INVOKE LICENSE-DESCRIPTION PFX=" * " PROGRAM=(get "Name") OWNER=(get "Author") \+]
+ */
 
 #include <gtkmm.h>
 #include <iostream>
@@ -23,7 +21,7 @@
 
 [+IF (=(get "HaveBuilderUI") "1")+]
 /* For testing propose use the local (not installed) ui file */
-/* #define UI_FILE PACKAGE_DATA_DIR"/[+NameHLower+]/ui/[+NameHLower+].ui" */
+/* #define UI_FILE PACKAGE_DATA_DIR"/ui/[+NameHLower+].ui" */
 #define UI_FILE "src/[+NameHLower+].ui"
 [+ENDIF+]
    
